@@ -69,9 +69,6 @@ namespace Tomboy
 			try {
 				return Gtk.IconTheme.Default.LoadIcon (resource_name, size, 0);
 			} catch (GLib.GException e) {
-				Logger.Log ("Unable to load icon '{0}': {1}", 
-					    resource_name, 
-					    e.Message);
 			}
 
 			try {
@@ -80,6 +77,7 @@ namespace Tomboy
 			} catch (ArgumentException e) {
 			}
 
+			Logger.Log ("Unable to load icon '{0}'.", resource_name);
 			return null;
 		}
 
@@ -105,6 +103,36 @@ namespace Tomboy
 			Gtk.Image image = new Gtk.Image (stock_id, Gtk.IconSize.Button);
 			return MakeImageButton (image, label);
 		}
+
+		public static void ShowHelp (string filename, 
+					     string link_id, 
+					     Gdk.Screen screen, 
+					     Gtk.Window parent)
+		{
+			try {
+				Gnome.Help.DisplayDesktopOnScreen (
+					Gnome.Program.Get (),
+					Defines.GNOME_HELP_DIR,
+					filename, 
+					link_id, 
+					screen);
+			} catch (GLib.GException e) {
+				string message = 
+					Catalog.GetString ("The \"Tomboy Notes Manual\" could " +
+							   "not be found.  Please verify " +
+							   "that your installation has been " +
+							   "completed successfully.");
+				HIGMessageDialog dialog = 
+					new HIGMessageDialog (parent,
+							      Gtk.DialogFlags.DestroyWithParent,
+							      Gtk.MessageType.Error,
+							      Gtk.ButtonsType.Ok,
+							      Catalog.GetString ("Help not found"),
+							      message);
+				dialog.Run ();
+				dialog.Destroy ();
+			}
+		}
 	}
 
 	public class GlobalKeybinder 
@@ -188,6 +216,7 @@ namespace Tomboy
 			}
 
 			image.Show ();
+			image.Yalign = 0;
 			hbox.PackStart (image, false, false, 0);
 			
 			Gtk.VBox label_vbox = new Gtk.VBox (false, 0);
@@ -461,6 +490,11 @@ namespace Tomboy
 			buffer.DeleteMark (start_mark);
 			buffer.DeleteMark (end_mark);
 		}
+
+		public void RemoveTag (Gtk.TextTag tag)
+		{
+			buffer.RemoveTag (tag, Start, End);
+		}
 	}
 
 	public class TextTagEnumerator : IEnumerator, IEnumerable
@@ -630,11 +664,8 @@ namespace Tomboy
 				       Gtk.Menu menu)
 		{
 			this.CanFocus = true;
-			this.Relief = Gtk.ReliefStyle.None;
-
-			// FIXME: Not implemented in Gtk#1
-			//this.Relief = toolbar.ReliefStyle;
-			//this.FocusOnClick = false;
+			this.Relief = toolbar.ReliefStyle;
+			this.FocusOnClick = false;
 
 			this.is_important = false;
 
@@ -747,6 +778,7 @@ namespace Tomboy
 	public class Application
 	{
 		static Gnome.Program program;
+		static ActionManager action_manager;
 
 		public static void Initialize (string locale_dir, 
 					       string display_name, 
@@ -755,14 +787,14 @@ namespace Tomboy
 		{
 			SetProcessName (process_name);
 
-			// Initialize GETTEXT
-			Catalog.Init (locale_dir, Defines.GNOME_LOCALE_DIR);
-
 			Gtk.Application.Init ();
 			program = new Gnome.Program ("Tomboy", 
 						     Defines.VERSION, 
 						     Gnome.Modules.UI, 
 						     args);
+			
+			action_manager = new ActionManager ();
+			action_manager.LoadInterface ();
 
 			RegisterSignalHandlers ();
 		}
@@ -865,5 +897,10 @@ namespace Tomboy
 		{
 			Gtk.Main.Quit ();
 		}
+		
+		public static ActionManager ActionManager
+		{
+			get { return action_manager; }
+		}
 	}
 }
